@@ -5,7 +5,7 @@ use v5.10.0;
 use strict;
 use warnings;
 
-use version 0.77; our $VERSION = version->declare('v0.3.0');
+use version 0.77; our $VERSION = version->declare('v0.3.1');
 
 use Carp qw/ croak /;
 use List::MoreUtils qw/ natatime /;
@@ -205,7 +205,7 @@ sub _compile_rule {
             return sub {
                 my $hash = $_[0];
                 $fn->( sub { $match->( $hash->{$_} ) },
-                       grep { $key_ref } (keys %{$hash}) );
+                       grep { $_ =~ $key } (keys %{$hash}) );
             };
 
         } else {
